<?php

namespace Drupal\epositivity\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Link;

/**
 * Configure epositivity settings.
 */
class EpositivitySettingsForm extends ConfigFormBase {
    /** @var string Config settings */
  const SETTINGS = 'epositivity.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'epositivity_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $form['test_mode'] = array(
      '#type' => 'checkbox',
      '#title' => t('Attiva modalità di test.'),
      '#description' => t('Attivando la modalità di test verranno utilizzate le impostazioni di test del modulo'),
      '#default_value' => $config->get('test_mode'),
    );


    /* Production Fieldset */
    $form['production_settings'] = array(
      '#type' => 'fieldset',
      '#title' => t('Parametri modalità in produzione'),
    );

    $form['production_settings']['storename'] = array(
      '#type' => 'textfield',
      '#title' => t('Storename'),
      '#default_value' => $config->get('storename'),
      '#description' => t('Definito anche <em>Terminal id</em>. Id del terminale fornito dal Servizio Esercenti'),
    );

    $form['production_settings']['ksig'] = array(
      '#type' => 'textfield',
      '#title' => t('Ksig'),
      '#default_value' => $config->get('ksig'),
      '#description' => t('La chiave segreta fornita dal Servizio Esercenti'),
    );

    $form['production_settings']['server_url'] = array(
      '#type' => 'textfield',
      '#title' => t('Server URL'),
      '#default_value' => $config->get('server_url'),
      '#description' => t('L\'URL fornito dal Servizio Esercenti'),
    );

    /* Test Fieldset */
    $form['test_settings'] = array(
      '#type' => 'fieldset',
      '#title' => t('Parametri modalità di test'),
    );

    $form['test_settings']['storename_test'] = array(
      '#type' => 'textfield',
      '#title' => t('Storename'),
      '#default_value' => $config->get('storename_test'),
      '#description' => t('Definito anche <em>Terminal id</em>. Id del terminale fornito dal Servizio Esercenti'),
    );

    $form['test_settings']['ksig_test'] = array(
      '#type' => 'textfield',
      '#title' => t('Ksig'),
      '#default_value' => $config->get('ksig_test'),
      '#description' => t('La chiave segreta fornita dal Servizio Esercenti'),
    );

    $form['test_settings']['server_url_test'] = array(
      '#type' => 'textfield',
      '#title' => t('Server URL'),
      '#default_value' => $config->get('server_url_test'),
      '#description' => t('L\'URL fornito dal Servizio Esercenti'),
    );

    /* Mode */
    $form['type_mode'] = array(
      '#type' => 'fieldset',
      '#title' => t('Modalità operativa'),
    );

    $form['type_mode']['info_type_mode'] = array(
      '#type' => 'markup',
      '#markup' => t('Impostazioni operative del POS'),
    );

    $form['type_mode']['txntype'] = array(
      '#type' => 'select',
      '#options' => array(
        'PURCHASE' => t('Movimentazione (PURCHASE)'),
      ),
      '#title' => t('Tipo di transazione'),
      '#description' => t('<p>Il gateway di pagamento può funzionare in diverse modalità, sono descritte al capitolo 5.A del manuale.</p>
        <ul>
          <li><em>Movimentazione (PURCHASE)</em> Autorizzazione con movimentazione contabile.</li>
          <li><em>Autorizzazione (AUTH)</em> Autorizzazione di una transazione con impegno dell\'importo <strong>senza movimentazione contabile</strong>.</li>
          <li><em>Conferma (CONFIRM)</em> Movimentazione di una transazione precedentemente autorizzata.</li>
          <li><em>Credito (CREDIT)</em> Storno di una transazione movimentata.</li>
          <li><em>Storno (VOID)</em> Storno di una transazione autorizzata</li>
        </ul>
      '),
      '#default_value' => $config->get('txntype'),
    );

    $form['type_mode']['mode'] = array(
      '#type' => 'select',
      '#options' => array(
        'payonly' => 'payonly',
      ),
      '#title' => t('Mode'),
      '#description' => t('Tipologia di pagamento. Parametro fisso. Pagina 21 del manuale.'),
      '#default_value' => $config->get('mode'),
    );


    /* Internationalization */
    $form['l10n'] = array(
      '#type' => 'fieldset',
      '#title' => t('Internazionalizzazione'),
    );

    $form['l10n']['timezone'] = array(
      '#type' => 'select',
      '#options' => array(
        'CET' => 'CET - Central European Time',
        'GMT' => 'GMT - Greenwich Mean Time',
        'EET' => 'EET - Eastern European Time',
      ),
      '#title' => t('Timezone'),
      '#description' => t('Il fuso orario della transazione. <strong>CET è il fuso orario in uso in Italia.</strong>'),
      '#default_value' => $config->get('timezone'),
    );

    $form['l10n']['language'] = array(
      '#type' => 'select',
      '#options' => array(
        'IT' => t('IT - Italiano'),
        'EN' => t('EN - Inglese'),
        'DE' => t('DE - Tedesco'),
      ),
      '#title' => t('Default language'),
      '#description' => t('Il gateway di pagamento supporta come lingua: Italiano, Inglese, Tedesco. Nel caso in cui non venga identificata in automatico la lingua del visitatore, oppure il visitatore usa una lingua diversa da quelle supportate dal gateway, verrà usato questo parametro.'),
      '#default_value' => $config->get('language'),
    );


    $form['l10n']['currency'] = array(
      '#type' => 'select',
      '#options' => array(
        'EUR' => t('EUR - Euro'),
        'AED' => t('AED - Dirham degli Emirati Arabi Uniti'),
        'AUD' => t('AUD - Dollaro australiano'),
        'BRL' => t('BRL - Real brasiliano'),
        'CAD' => t('CAD - Dollaro canadese'),
        'CHF' => t('CHF - Franco svizzero'),
        'DKK' => t('DKK - Corona danese'),
        'GBP' => t('GBP - Sterlina britannica'),
        'HKD' => t('HKD - Dollaro di Hong Kong'),
        'JPY' => t('JPY - Yen giapponese'),
        'KWD' => t('KWD - Dinaro kuwaitiano'),
        'MXN' => t('MXN - Peso messicano'),
        'MYR' => t('MYR - Ringgit malese'),
        'NOK' => t('NOK - Corona norvegese'),
        'RUB' => t('RUB - Rublo russo'),
        'SAR' => t('SAR - Rial saudita'),
        'SEK' => t('SEK - Corona svedese'),
        'SGD' => t('SGD - Dollaro di Singapore'),
        'THB' => t('THB - Baht thailandese'),
        'TWD' => t('TWD - Nuovo dollaro taiwanese'),
        'USD' => t('USD - Dollaro statunitense'),
      ),
      '#title' => t('Valuta della transazione'),
      '#description' => t('La valuta con cui sarà effettuata la transazione.'),
      '#default_value' => $config->get('currency'),
    );

    $form['info_url'] = array(
      '#type' => 'markup',
      '#markup' => t('<h3>URL backend</h3>
        <ul>
          <li>response_success_url: @response_success_url</li>
          <li>response_fail_url: @response_fail_url</li>
          <li>transaction_notification_url: @transaction_notification_url</li>
        </ul>
        ',
        array(
          '@response_success_url' => $config->get('response_success_url'),
          '@response_fail_url' => $config->get('response_fail_url'),
          '@transaction_notification_url' => $config->get('transaction_notification_url'),
        )
      ),
    );

    $form['info_version'] = array(
      '#type' => 'markup',
      '#markup' => t('<h3>Versione</h3><p>Questo modulo è basato sulla versione <strong>@version</strong> del gateway di pagamento <strong>BNL e-POSitivity.</strong></p>', array('@version' => $config->get('gateway_version') )),
    );

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

   $this->configFactory->getEditable(static::SETTINGS)
      ->set( 'test_mode'      , $form_state->getValue('test_mode'))
      ->set( 'storename'      , $form_state->getValue('storename'))
      ->set( 'ksig'           , $form_state->getValue('ksig'))
      ->set( 'server_url'     , $form_state->getValue('server_url'))
      ->set( 'storename_test' , $form_state->getValue('storename_test'))
      ->set( 'ksig_test'      , $form_state->getValue('ksig_test'))
      ->set( 'server_url_test', $form_state->getValue('server_url_test'))
      ->set( 'txntype'        , $form_state->getValue('txntype'))
      ->set( 'mode'           , $form_state->getValue('mode'))
      ->set( 'timezone'       , $form_state->getValue('timezone'))
      ->set( 'language'       , $form_state->getValue('language'))
      ->set( 'currency'       , $form_state->getValue('currency'))
      ->save();

    parent::submitForm($form, $form_state);
  }
}
